<div class="landing-logos">
  <div class="tsam-logo-light">
    <img src="assets/tsam-logo-light.svg" alt="ETHOS.TSAM">
  </div>
  <div class="tsam-logo-dark">
    <img src="assets/tsam-logo-dark.svg" alt="ETHOS.TSAM">
  </div>
  <div class="jsa-logo">
    <a href="https://www.fz-juelich.de/en/iek/iek-3">
      <img src="assets/JSA-Header.svg" alt="Jülich System Analysis">
    </a>
  </div>
</div>

# Introduction

## ETHOS.TSAM - Time Series Aggregation Module

ETHOS.TSAM is a python package which uses different machine learning algorithms for the aggregation of typical periods. It is applicable
for all type of time series, either weather data, price data, behavioral data, electrical load data or all together. The module is able to significantly reduce input
time series for mathematical models, and therefore the model's complexity and computational time.


To use ETHOS.TSAM, first [install ETHOS.TSAM](installation.md) and then [start aggregating time series](getting-started.md).

ETHOS.TSAM is open-source available on [GitHub](https://github.com/FZJ-IEK3-VSA/tsam)
and open for collaboration, help requests etc.
In case you use ETHOS.TSAM in a scientific publication, we kindly request you to cite one of our publications listed in the
[Further Reading Section](further-reading.md).

ETHOS.TSAM is part of the [Energy Transformation PatHway Optimization Suite (ETHOS) at ICE-2](https://www.fz-juelich.de/de/ice/ice-2/leistungen/model-services). It is tightly integrated into [ETHOS.FINE](https://github.com/FZJ-IEK3-VSA/FINE) to reduce the temporal complexity of energy system models.
